@@ -43,7 +43,7 @@ import Database.Record (ToSql, FromSql)
 import Database.Record.TH (recordTemplate, defineSqlPersistableInstances)
 import Database.Relational
   (Config, nameConfig, recordConfig, enableWarning, verboseAsCompilerWarning,
-   defaultConfig, Relation, relationalQuerySQL, QuerySuffix)
+   defaultConfig, Relation, untypeQuery, relationalQuery_, QuerySuffix)
 import qualified Database.Relational.TH as Relational
 
 import Database.HDBC.Session (withConnectionIO)
@@ -181,7 +181,7 @@ inlineVerifiedQuery :: IConnection conn
                     -> Q [Dec]      -- ^ Result declarations
 inlineVerifiedQuery connect relVar rel config sufs qns = do
   (p, r) <- Relational.reifyRelation relVar
-  let sql = relationalQuerySQL config rel sufs
+  let sql = untypeQuery $ relationalQuery_ config rel sufs
   when (verboseAsCompilerWarning config) . reportWarning $ "Verify with prepare: " ++ sql
   void . runIO $ withConnectionIO connect (\conn -> prepare conn sql)
   Relational.unsafeInlineQuery (return p) (return r) sql (varCamelcaseName qns)
